@@ -6,6 +6,7 @@ import logging
 from configparser import ConfigParser
 
 from aws_xray_sdk import global_sdk_config
+from aws_xray_sdk.core.async_context import AsyncContext
 from aws_xray_sdk.core import xray_recorder, patch_all, patch
 from aws_xray_sdk.core.utils import stacktrace
 from aws_xray_sdk.ext.flask.middleware import XRayMiddleware
@@ -36,6 +37,7 @@ class XRaySettingsConfigParser:
             self.sqlalchemy = xray.getboolean("SQLALCHEMY", False)
             self.middleware = xray.getboolean("MIDDLEWARE", True)
             self.sentry_logging = xray.getboolean("SENTRY_LOGGING", False)
+            self.async_context = xray.getboolean("ASYNC_CONTEXT", False)
         else:
             self.enabled = False
             self.service_name = None
@@ -48,6 +50,7 @@ class XRaySettingsConfigParser:
             self.sqlalchemy = False
             self.middleware = True
             self.sentry_logging = False
+            self.async_context = False
 
 
 class XRaySettingsLazySettings:
@@ -63,6 +66,7 @@ class XRaySettingsLazySettings:
         self.sqlalchemy = settings.XRAY_SQLALCHEMY
         self.middleware = settings.XRAY_MIDDLEWARE
         self.sentry_logging = settings.XRAY_SENTRY_LOGGING
+        self.async_context = settings.XRAY_ASYNC_CONTEXT
 
 
 class XRayConfigurator:
@@ -97,6 +101,7 @@ class XRayConfigurator:
             stream_sql=settings.stream_sql,
             daemon_address=settings.daemon,
             context_missing="LOG_ERROR",
+            context=AsyncContext() if settings.async_context else None,
         )
         if not settings.patch_modules:
             patch_all()
